Skip to contents

Displays information about the webrarian cache, including installed webR versions, cached packages, and total size.

Usage

webr_cache_info()

Value

Invisibly returns a list with the cache path, whether it exists, the installed webR versions, a packages data frame with one row per R version in the package download cache (r_version, packages, size), and the total_size in bytes.

Examples

webr_cache_info()
#> 
#> ── Webrarian Cache ──
#> 
#> Location: /home/runner/.cache/R/webrarian
#> 
#> ℹ Cache directory does not exist